Removal of deprecated ``mathtext`` APIs
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

The following `matplotlib.mathtext` APIs have been removed:

- ``Fonts`` and all its subclasses,
- ``FontConstantsBase`` and all its subclasses,
- ``Node`` and all its subclasses,
- ``Ship``, ``ship``,
- ``Error``,
- ``Parser``,
- ``SHRINK_FACTOR``, ``GROW_FACTOR``,
- ``NUM_SIZE_LEVELS``,
- ``latex_to_bakoma``, ``latex_to_cmex``, ``latex_to_standard``,
- ``stix_virtual_fonts``,
- ``tex2uni``

Removal of various ``mathtext`` helpers
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

The following `matplotlib.mathtext` classes:

- ``MathtextBackendPdf``,
- ``MathtextBackendPs``,
- ``MathtextBackendSvg``,
- ``MathtextBackendCairo``,

and the ``.mathtext_parser`` attributes on

- `.RendererPdf`,
- `.RendererPS`,
- `.RendererSVG`,
- `.RendererCairo`

have been removed. The `.MathtextBackendPath` class can be used instead.

The methods ``get_depth``, ``parse``, ``to_mask``, ``to_rgba``, and ``to_png``
of `.MathTextParser` have been removed. Use `.mathtext.math_to_image` instead.

The unused ``StandardPsFonts.pswriter`` has been removed.

``ps.useafm`` removed for ``mathtext``
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

The setting :rc:`ps.useafm` no longer has any effect on `matplotlib.mathtext`.
